# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/mdb/mdb.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/mdb/mdb.proto',
  package='yamcs.protobuf.mdb',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n\x1cyamcs/protobuf/mdb/mdb.proto\x12\x12yamcs.protobuf.mdb\x1a\x1ayamcs/protobuf/yamcs.proto\"~\n\x0fMissionDatabase\x12\x12\n\nconfigName\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x38\n\x0bspaceSystem\x18\x04 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\"M\n\x0bHistoryInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\"\x18\n\x08UnitInfo\x12\x0c\n\x04unit\x18\x01 \x01(\t\"\x97\x01\n\nAlarmRange\x12\x31\n\x05level\x18\x01 \x01(\x0e\x32\".yamcs.protobuf.mdb.AlarmLevelType\x12\x14\n\x0cminInclusive\x18\x02 \x01(\x01\x12\x14\n\x0cmaxInclusive\x18\x03 \x01(\x01\x12\x14\n\x0cminExclusive\x18\x04 \x01(\x01\x12\x14\n\x0cmaxExclusive\x18\x05 \x01(\x01\"T\n\x10\x45numerationAlarm\x12\x31\n\x05level\x18\x01 \x01(\x0e\x32\".yamcs.protobuf.mdb.AlarmLevelType\x12\r\n\x05label\x18\x03 \x01(\t\"\x9c\x01\n\tAlarmInfo\x12\x15\n\rminViolations\x18\x01 \x01(\x05\x12\x38\n\x10staticAlarmRange\x18\x02 \x03(\x0b\x32\x1e.yamcs.protobuf.mdb.AlarmRange\x12>\n\x10\x65numerationAlarm\x18\x03 \x03(\x0b\x32$.yamcs.protobuf.mdb.EnumerationAlarm\"\x89\x01\n\x10\x43ontextAlarmInfo\x12\x36\n\ncomparison\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfo\x12,\n\x05\x61larm\x18\x02 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\"\xd1\x02\n\x10\x44\x61taEncodingInfo\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).yamcs.protobuf.mdb.DataEncodingInfo.Type\x12\x14\n\x0clittleEndian\x18\x02 \x01(\x08\x12\x12\n\nsizeInBits\x18\x03 \x01(\x05\x12\x10\n\x08\x65ncoding\x18\x04 \x01(\t\x12=\n\x11\x64\x65\x66\x61ultCalibrator\x18\x06 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12\x44\n\x11\x63ontextCalibrator\x18\x07 \x03(\x0b\x32).yamcs.protobuf.mdb.ContextCalibratorInfo\"C\n\x04Type\x12\n\n\x06\x42INARY\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x0b\n\x07INTEGER\x10\x03\x12\n\n\x06STRING\x10\x04\"\x98\x01\n\x15\x43ontextCalibratorInfo\x12\x36\n\ncomparison\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfo\x12\x36\n\ncalibrator\x18\x02 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\t\"\xf8\x02\n\x0e\x43\x61libratorInfo\x12J\n\x14polynomialCalibrator\x18\x02 \x01(\x0b\x32,.yamcs.protobuf.mdb.PolynomialCalibratorInfo\x12\x42\n\x10splineCalibrator\x18\x03 \x01(\x0b\x32(.yamcs.protobuf.mdb.SplineCalibratorInfo\x12R\n\x18javaExpressionCalibrator\x18\x04 \x01(\x0b\x32\x30.yamcs.protobuf.mdb.JavaExpressionCalibratorInfo\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.yamcs.protobuf.mdb.CalibratorInfo.Type\"K\n\x04Type\x12\x0e\n\nPOLYNOMIAL\x10\x00\x12\n\n\x06SPLINE\x10\x01\x12\x12\n\x0eMATH_OPERATION\x10\x02\x12\x13\n\x0fJAVA_EXPRESSION\x10\x03\"/\n\x18PolynomialCalibratorInfo\x12\x13\n\x0b\x63oefficient\x18\x01 \x03(\x01\"\x93\x01\n\x14SplineCalibratorInfo\x12G\n\x05point\x18\x01 \x03(\x0b\x32\x38.yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo\x1a\x32\n\x0fSplinePointInfo\x12\x0b\n\x03raw\x18\x01 \x01(\x01\x12\x12\n\ncalibrated\x18\x02 \x01(\x01\"/\n\x1cJavaExpressionCalibratorInfo\x12\x0f\n\x07\x66ormula\x18\x01 \x01(\t\")\n\tEnumValue\x12\r\n\x05value\x18\x01 \x01(\x03\x12\r\n\x05label\x18\x02 \x01(\t\"\xf2\x02\n\x11ParameterTypeInfo\x12\x0f\n\x07\x65ngType\x18\x01 \x01(\t\x12:\n\x0c\x64\x61taEncoding\x18\x02 \x01(\x0b\x32$.yamcs.protobuf.mdb.DataEncodingInfo\x12-\n\x07unitSet\x18\x03 \x03(\x0b\x32\x1c.yamcs.protobuf.mdb.UnitInfo\x12\x33\n\x0c\x64\x65\x66\x61ultAlarm\x18\x04 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12\x30\n\tenumValue\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumValue\x12>\n\x10\x61\x62soluteTimeInfo\x18\x06 \x01(\x0b\x32$.yamcs.protobuf.mdb.AbsoluteTimeInfo\x12:\n\x0c\x63ontextAlarm\x18\x07 \x03(\x0b\x32$.yamcs.protobuf.mdb.ContextAlarmInfo\"\x8d\x01\n\x10\x41\x62soluteTimeInfo\x12\x14\n\x0cinitialValue\x18\x01 \x01(\t\x12\r\n\x05scale\x18\x02 \x01(\x01\x12\x0e\n\x06offset\x18\x03 \x01(\x01\x12\x35\n\noffsetFrom\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\r\n\x05\x65poch\x18\x05 \x01(\t\"x\n\nUsedByInfo\x12\x34\n\talgorithm\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\x12\x34\n\tcontainer\x18\x02 \x03(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\"\xb2\x02\n\rParameterInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x33\n\x04type\x18\x06 \x01(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfo\x12\x36\n\ndataSource\x18\x07 \x01(\x0e\x32\".yamcs.protobuf.mdb.DataSourceType\x12.\n\x06usedBy\x18\x08 \x01(\x0b\x32\x1e.yamcs.protobuf.mdb.UsedByInfo\"\xe4\x01\n\x10\x41rgumentTypeInfo\x12\x0f\n\x07\x65ngType\x18\x01 \x01(\t\x12:\n\x0c\x64\x61taEncoding\x18\x02 \x01(\x0b\x32$.yamcs.protobuf.mdb.DataEncodingInfo\x12-\n\x07unitSet\x18\x03 \x03(\x0b\x32\x1c.yamcs.protobuf.mdb.UnitInfo\x12\x30\n\tenumValue\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumValue\x12\x10\n\x08rangeMin\x18\x06 \x01(\x01\x12\x10\n\x08rangeMax\x18\x07 \x01(\x01\"{\n\x0c\x41rgumentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0cinitialValue\x18\x04 \x01(\t\x12\x32\n\x04type\x18\x06 \x01(\x0b\x32$.yamcs.protobuf.mdb.ArgumentTypeInfo\"5\n\x16\x41rgumentAssignmentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe5\x01\n\x10SignificanceInfo\x12T\n\x10\x63onsequenceLevel\x18\x01 \x01(\x0e\x32:.yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType\x12\x18\n\x10reasonForWarning\x18\x02 \x01(\t\"a\n\x15SignificanceLevelType\x12\x08\n\x04NONE\x10\x01\x12\t\n\x05WATCH\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x0c\n\x08\x44ISTRESS\x10\x04\x12\x0c\n\x08\x43RITICAL\x10\x05\x12\n\n\x06SEVERE\x10\x06\"\xa9\x02\n\x0e\x43omparisonInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x41\n\x08operator\x18\x02 \x01(\x0e\x32/.yamcs.protobuf.mdb.ComparisonInfo.OperatorType\x12\r\n\x05value\x18\x03 \x01(\t\"\x8e\x01\n\x0cOperatorType\x12\x0c\n\x08\x45QUAL_TO\x10\x01\x12\x10\n\x0cNOT_EQUAL_TO\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x1c\n\x18GREATER_THAN_OR_EQUAL_TO\x10\x04\x12\x10\n\x0cSMALLER_THAN\x10\x05\x12\x1c\n\x18SMALLER_THAN_OR_EQUAL_TO\x10\x06\"e\n\x1aTransmissionConstraintInfo\x12\x36\n\ncomparison\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfo\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"\x9b\x04\n\x0b\x43ommandInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x34\n\x0b\x62\x61seCommand\x18\x06 \x01(\x0b\x32\x1f.yamcs.protobuf.mdb.CommandInfo\x12\x10\n\x08\x61\x62stract\x18\x07 \x01(\x08\x12\x32\n\x08\x61rgument\x18\x08 \x03(\x0b\x32 .yamcs.protobuf.mdb.ArgumentInfo\x12\x46\n\x12\x61rgumentAssignment\x18\t \x03(\x0b\x32*.yamcs.protobuf.mdb.ArgumentAssignmentInfo\x12:\n\x0csignificance\x18\n \x01(\x0b\x32$.yamcs.protobuf.mdb.SignificanceInfo\x12\x42\n\nconstraint\x18\x0b \x03(\x0b\x32..yamcs.protobuf.mdb.TransmissionConstraintInfo\x12\x42\n\x10\x63ommandContainer\x18\r \x01(\x0b\x32(.yamcs.protobuf.mdb.CommandContainerInfo\"n\n\nRepeatInfo\x12\x12\n\nfixedCount\x18\x01 \x01(\x03\x12\x37\n\x0c\x64ynamicCount\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x13\n\x0b\x62itsBetween\x18\x03 \x01(\x05\"\xcd\x03\n\x11SequenceEntryInfo\x12\x16\n\x0elocationInBits\x18\x01 \x01(\x05\x12V\n\x11referenceLocation\x18\x02 \x01(\x0e\x32;.yamcs.protobuf.mdb.SequenceEntryInfo.ReferenceLocationType\x12\x34\n\tcontainer\x18\x03 \x01(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12\x34\n\tparameter\x18\x04 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x32\n\x08\x61rgument\x18\x06 \x01(\x0b\x32 .yamcs.protobuf.mdb.ArgumentInfo\x12\x36\n\nfixedValue\x18\x07 \x01(\x0b\x32\".yamcs.protobuf.mdb.FixedValueInfo\x12.\n\x06repeat\x18\x05 \x01(\x0b\x32\x1e.yamcs.protobuf.mdb.RepeatInfo\"@\n\x15ReferenceLocationType\x12\x13\n\x0f\x43ONTAINER_START\x10\x01\x12\x12\n\x0ePREVIOUS_ENTRY\x10\x02\"D\n\x0e\x46ixedValueInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08hexValue\x18\x02 \x01(\t\x12\x12\n\nsizeInBits\x18\x03 \x01(\x05\"\xa7\x02\n\x14\x43ommandContainerInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x12\n\nsizeInBits\x18\x06 \x01(\x05\x12?\n\rbaseContainer\x18\x07 \x01(\x0b\x32(.yamcs.protobuf.mdb.CommandContainerInfo\x12\x34\n\x05\x65ntry\x18\x08 \x03(\x0b\x32%.yamcs.protobuf.mdb.SequenceEntryInfo\"\x9f\x03\n\rContainerInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x13\n\x0bmaxInterval\x18\x06 \x01(\x03\x12\x12\n\nsizeInBits\x18\x07 \x01(\x05\x12\x38\n\rbaseContainer\x18\x08 \x01(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12?\n\x13restrictionCriteria\x18\t \x03(\x0b\x32\".yamcs.protobuf.mdb.ComparisonInfo\x12\x34\n\x05\x65ntry\x18\n \x03(\x0b\x32%.yamcs.protobuf.mdb.SequenceEntryInfo\x12.\n\x06usedBy\x18\x0b \x01(\x0b\x32\x1e.yamcs.protobuf.mdb.UsedByInfo\"\x8b\x01\n\x12InputParameterInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x11\n\tinputName\x18\x02 \x01(\t\x12\x19\n\x11parameterInstance\x18\x03 \x01(\x05\x12\x11\n\tmandatory\x18\x04 \x01(\x08\"_\n\x13OutputParameterInfo\x12\x34\n\tparameter\x18\x01 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x12\n\noutputName\x18\x02 \x01(\t\"\xf4\x03\n\rAlgorithmInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12,\n\x05\x61lias\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x36\n\x05scope\x18\x06 \x01(\x0e\x32\'.yamcs.protobuf.mdb.AlgorithmInfo.Scope\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x0c\n\x04text\x18\x08 \x01(\t\x12>\n\x0einputParameter\x18\t \x03(\x0b\x32&.yamcs.protobuf.mdb.InputParameterInfo\x12@\n\x0foutputParameter\x18\n \x03(\x0b\x32\'.yamcs.protobuf.mdb.OutputParameterInfo\x12<\n\x11onParameterUpdate\x18\x0b \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x16\n\x0eonPeriodicRate\x18\x0c \x03(\x03\"-\n\x05Scope\x12\n\n\x06GLOBAL\x10\x00\x12\x18\n\x14\x43OMMAND_VERIFICATION\x10\x01\"|\n\x16ListParametersResponse\x12\x34\n\tparameter\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"\x7f\n\x1aListParameterTypesResponse\x12\x33\n\x04type\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.mdb.ParameterTypeInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"H\n\x1b\x42ulkGetParameterInfoRequest\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\"\xf8\x01\n\x1c\x42ulkGetParameterInfoResponse\x12[\n\x08response\x18\x01 \x03(\x0b\x32I.yamcs.protobuf.mdb.BulkGetParameterInfoResponse.GetParameterInfoResponse\x1a{\n\x18GetParameterInfoResponse\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x34\n\tparameter\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfo\"|\n\x16ListContainersResponse\x12\x34\n\tcontainer\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.ContainerInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"v\n\x14ListCommandsResponse\x12\x30\n\x07\x63ommand\x18\x01 \x03(\x0b\x32\x1f.yamcs.protobuf.mdb.CommandInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"|\n\x16ListAlgorithmsResponse\x12\x34\n\talgorithm\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"\x82\x01\n\x18ListSpaceSystemsResponse\x12\x38\n\x0bspaceSystem\x18\x01 \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\x12\x11\n\ttotalSize\x18\x03 \x01(\x05\"\xbc\x02\n\x0fSpaceSystemInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rqualifiedName\x18\x02 \x01(\t\x12\x18\n\x10shortDescription\x18\x03 \x01(\t\x12\x17\n\x0flongDescription\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x16\n\x0eparameterCount\x18\x06 \x01(\x05\x12\x16\n\x0e\x63ontainerCount\x18\x07 \x01(\x05\x12\x14\n\x0c\x63ommandCount\x18\x08 \x01(\x05\x12\x16\n\x0e\x61lgorithmCount\x18\t \x01(\x05\x12\x30\n\x07history\x18\x0e \x03(\x0b\x32\x1f.yamcs.protobuf.mdb.HistoryInfo\x12\x30\n\x03sub\x18\x0f \x03(\x0b\x32#.yamcs.protobuf.mdb.SpaceSystemInfo\"\xf1\x03\n\x16\x43hangeParameterRequest\x12\x45\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x35.yamcs.protobuf.mdb.ChangeParameterRequest.ActionType\x12=\n\x11\x64\x65\x66\x61ultCalibrator\x18\x02 \x01(\x0b\x32\".yamcs.protobuf.mdb.CalibratorInfo\x12\x44\n\x11\x63ontextCalibrator\x18\x03 \x03(\x0b\x32).yamcs.protobuf.mdb.ContextCalibratorInfo\x12\x33\n\x0c\x64\x65\x66\x61ultAlarm\x18\x04 \x01(\x0b\x32\x1d.yamcs.protobuf.mdb.AlarmInfo\x12:\n\x0c\x63ontextAlarm\x18\x05 \x03(\x0b\x32$.yamcs.protobuf.mdb.ContextAlarmInfo\"\x99\x01\n\nActionType\x12\t\n\x05RESET\x10\x00\x12\x15\n\x11RESET_CALIBRATORS\x10\x01\x12\x1a\n\x16SET_DEFAULT_CALIBRATOR\x10\x02\x12\x13\n\x0fSET_CALIBRATORS\x10\x03\x12\x10\n\x0cRESET_ALARMS\x10\x04\x12\x16\n\x12SET_DEFAULT_ALARMS\x10\x05\x12\x0e\n\nSET_ALARMS\x10\x06\"\xb7\x01\n\x16\x43hangeAlgorithmRequest\x12\x45\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x35.yamcs.protobuf.mdb.ChangeAlgorithmRequest.ActionType\x12\x34\n\talgorithm\x18\x02 \x01(\x0b\x32!.yamcs.protobuf.mdb.AlgorithmInfo\" \n\nActionType\x12\t\n\x05RESET\x10\x00\x12\x07\n\x03SET\x10\x01*\xa2\x01\n\x0e\x44\x61taSourceType\x12\x0f\n\x0bTELEMETERED\x10\x00\x12\x0b\n\x07\x44\x45RIVED\x10\x01\x12\x0c\n\x08\x43ONSTANT\x10\x02\x12\t\n\x05LOCAL\x10\x03\x12\n\n\x06SYSTEM\x10\x04\x12\x0b\n\x07\x43OMMAND\x10\x05\x12\x13\n\x0f\x43OMMAND_HISTORY\x10\x06\x12\r\n\tEXTERNAL1\x10\x07\x12\r\n\tEXTERNAL2\x10\x08\x12\r\n\tEXTERNAL3\x10\t*\\\n\x0e\x41larmLevelType\x12\n\n\x06NORMAL\x10\x00\x12\t\n\x05WATCH\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\x0c\n\x08\x44ISTRESS\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\x12\n\n\x06SEVERE\x10\x05\x42\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])

_DATASOURCETYPE = _descriptor.EnumDescriptor(
  name='DataSourceType',
  full_name='yamcs.protobuf.mdb.DataSourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TELEMETERED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DERIVED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSTANT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_HISTORY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL1', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL2', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL3', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8748,
  serialized_end=8910,
)
_sym_db.RegisterEnumDescriptor(_DATASOURCETYPE)

DataSourceType = enum_type_wrapper.EnumTypeWrapper(_DATASOURCETYPE)
_ALARMLEVELTYPE = _descriptor.EnumDescriptor(
  name='AlarmLevelType',
  full_name='yamcs.protobuf.mdb.AlarmLevelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WATCH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISTRESS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8912,
  serialized_end=9004,
)
_sym_db.RegisterEnumDescriptor(_ALARMLEVELTYPE)

AlarmLevelType = enum_type_wrapper.EnumTypeWrapper(_ALARMLEVELTYPE)
TELEMETERED = 0
DERIVED = 1
CONSTANT = 2
LOCAL = 3
SYSTEM = 4
COMMAND = 5
COMMAND_HISTORY = 6
EXTERNAL1 = 7
EXTERNAL2 = 8
EXTERNAL3 = 9
NORMAL = 0
WATCH = 1
WARNING = 2
DISTRESS = 3
CRITICAL = 4
SEVERE = 5


_DATAENCODINGINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.mdb.DataEncodingInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTEGER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1123,
  serialized_end=1190,
)
_sym_db.RegisterEnumDescriptor(_DATAENCODINGINFO_TYPE)

_CALIBRATORINFO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.mdb.CalibratorInfo.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POLYNOMIAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPLINE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MATH_OPERATION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JAVA_EXPRESSION', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1649,
  serialized_end=1724,
)
_sym_db.RegisterEnumDescriptor(_CALIBRATORINFO_TYPE)

_SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE = _descriptor.EnumDescriptor(
  name='SignificanceLevelType',
  full_name='yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WATCH', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISTRESS', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3509,
  serialized_end=3606,
)
_sym_db.RegisterEnumDescriptor(_SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE)

_COMPARISONINFO_OPERATORTYPE = _descriptor.EnumDescriptor(
  name='OperatorType',
  full_name='yamcs.protobuf.mdb.ComparisonInfo.OperatorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQUAL_TO', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL_TO', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_OR_EQUAL_TO', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALLER_THAN', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMALLER_THAN_OR_EQUAL_TO', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3764,
  serialized_end=3906,
)
_sym_db.RegisterEnumDescriptor(_COMPARISONINFO_OPERATORTYPE)

_SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE = _descriptor.EnumDescriptor(
  name='ReferenceLocationType',
  full_name='yamcs.protobuf.mdb.SequenceEntryInfo.ReferenceLocationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_START', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREVIOUS_ENTRY', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5063,
  serialized_end=5127,
)
_sym_db.RegisterEnumDescriptor(_SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE)

_ALGORITHMINFO_SCOPE = _descriptor.EnumDescriptor(
  name='Scope',
  full_name='yamcs.protobuf.mdb.AlgorithmInfo.Scope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GLOBAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_VERIFICATION', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6610,
  serialized_end=6655,
)
_sym_db.RegisterEnumDescriptor(_ALGORITHMINFO_SCOPE)

_CHANGEPARAMETERREQUEST_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='yamcs.protobuf.mdb.ChangeParameterRequest.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET_CALIBRATORS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_DEFAULT_CALIBRATOR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_CALIBRATORS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET_ALARMS', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_DEFAULT_ALARMS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_ALARMS', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8406,
  serialized_end=8559,
)
_sym_db.RegisterEnumDescriptor(_CHANGEPARAMETERREQUEST_ACTIONTYPE)

_CHANGEALGORITHMREQUEST_ACTIONTYPE = _descriptor.EnumDescriptor(
  name='ActionType',
  full_name='yamcs.protobuf.mdb.ChangeAlgorithmRequest.ActionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8713,
  serialized_end=8745,
)
_sym_db.RegisterEnumDescriptor(_CHANGEALGORITHMREQUEST_ACTIONTYPE)


_MISSIONDATABASE = _descriptor.Descriptor(
  name='MissionDatabase',
  full_name='yamcs.protobuf.mdb.MissionDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configName', full_name='yamcs.protobuf.mdb.MissionDatabase.configName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.MissionDatabase.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.mdb.MissionDatabase.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spaceSystem', full_name='yamcs.protobuf.mdb.MissionDatabase.spaceSystem', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=206,
)


_HISTORYINFO = _descriptor.Descriptor(
  name='HistoryInfo',
  full_name='yamcs.protobuf.mdb.HistoryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.mdb.HistoryInfo.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='yamcs.protobuf.mdb.HistoryInfo.date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.mdb.HistoryInfo.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='author', full_name='yamcs.protobuf.mdb.HistoryInfo.author', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=285,
)


_UNITINFO = _descriptor.Descriptor(
  name='UnitInfo',
  full_name='yamcs.protobuf.mdb.UnitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='yamcs.protobuf.mdb.UnitInfo.unit', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=311,
)


_ALARMRANGE = _descriptor.Descriptor(
  name='AlarmRange',
  full_name='yamcs.protobuf.mdb.AlarmRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.mdb.AlarmRange.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minInclusive', full_name='yamcs.protobuf.mdb.AlarmRange.minInclusive', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxInclusive', full_name='yamcs.protobuf.mdb.AlarmRange.maxInclusive', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minExclusive', full_name='yamcs.protobuf.mdb.AlarmRange.minExclusive', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxExclusive', full_name='yamcs.protobuf.mdb.AlarmRange.maxExclusive', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=465,
)


_ENUMERATIONALARM = _descriptor.Descriptor(
  name='EnumerationAlarm',
  full_name='yamcs.protobuf.mdb.EnumerationAlarm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.mdb.EnumerationAlarm.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.mdb.EnumerationAlarm.label', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=551,
)


_ALARMINFO = _descriptor.Descriptor(
  name='AlarmInfo',
  full_name='yamcs.protobuf.mdb.AlarmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minViolations', full_name='yamcs.protobuf.mdb.AlarmInfo.minViolations', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticAlarmRange', full_name='yamcs.protobuf.mdb.AlarmInfo.staticAlarmRange', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumerationAlarm', full_name='yamcs.protobuf.mdb.AlarmInfo.enumerationAlarm', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=710,
)


_CONTEXTALARMINFO = _descriptor.Descriptor(
  name='ContextAlarmInfo',
  full_name='yamcs.protobuf.mdb.ContextAlarmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='yamcs.protobuf.mdb.ContextAlarmInfo.comparison', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarm', full_name='yamcs.protobuf.mdb.ContextAlarmInfo.alarm', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='yamcs.protobuf.mdb.ContextAlarmInfo.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=850,
)


_DATAENCODINGINFO = _descriptor.Descriptor(
  name='DataEncodingInfo',
  full_name='yamcs.protobuf.mdb.DataEncodingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.DataEncodingInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='littleEndian', full_name='yamcs.protobuf.mdb.DataEncodingInfo.littleEndian', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.DataEncodingInfo.sizeInBits', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='yamcs.protobuf.mdb.DataEncodingInfo.encoding', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultCalibrator', full_name='yamcs.protobuf.mdb.DataEncodingInfo.defaultCalibrator', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextCalibrator', full_name='yamcs.protobuf.mdb.DataEncodingInfo.contextCalibrator', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATAENCODINGINFO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=1190,
)


_CONTEXTCALIBRATORINFO = _descriptor.Descriptor(
  name='ContextCalibratorInfo',
  full_name='yamcs.protobuf.mdb.ContextCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='yamcs.protobuf.mdb.ContextCalibratorInfo.comparison', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibrator', full_name='yamcs.protobuf.mdb.ContextCalibratorInfo.calibrator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='yamcs.protobuf.mdb.ContextCalibratorInfo.context', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1193,
  serialized_end=1345,
)


_CALIBRATORINFO = _descriptor.Descriptor(
  name='CalibratorInfo',
  full_name='yamcs.protobuf.mdb.CalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='polynomialCalibrator', full_name='yamcs.protobuf.mdb.CalibratorInfo.polynomialCalibrator', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='splineCalibrator', full_name='yamcs.protobuf.mdb.CalibratorInfo.splineCalibrator', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='javaExpressionCalibrator', full_name='yamcs.protobuf.mdb.CalibratorInfo.javaExpressionCalibrator', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.CalibratorInfo.type', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CALIBRATORINFO_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1724,
)


_POLYNOMIALCALIBRATORINFO = _descriptor.Descriptor(
  name='PolynomialCalibratorInfo',
  full_name='yamcs.protobuf.mdb.PolynomialCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coefficient', full_name='yamcs.protobuf.mdb.PolynomialCalibratorInfo.coefficient', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1726,
  serialized_end=1773,
)


_SPLINECALIBRATORINFO_SPLINEPOINTINFO = _descriptor.Descriptor(
  name='SplinePointInfo',
  full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo.raw', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calibrated', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo.calibrated', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1873,
  serialized_end=1923,
)

_SPLINECALIBRATORINFO = _descriptor.Descriptor(
  name='SplineCalibratorInfo',
  full_name='yamcs.protobuf.mdb.SplineCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='yamcs.protobuf.mdb.SplineCalibratorInfo.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPLINECALIBRATORINFO_SPLINEPOINTINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1776,
  serialized_end=1923,
)


_JAVAEXPRESSIONCALIBRATORINFO = _descriptor.Descriptor(
  name='JavaExpressionCalibratorInfo',
  full_name='yamcs.protobuf.mdb.JavaExpressionCalibratorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='formula', full_name='yamcs.protobuf.mdb.JavaExpressionCalibratorInfo.formula', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=1972,
)


_ENUMVALUE = _descriptor.Descriptor(
  name='EnumValue',
  full_name='yamcs.protobuf.mdb.EnumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.EnumValue.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.mdb.EnumValue.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1974,
  serialized_end=2015,
)


_PARAMETERTYPEINFO = _descriptor.Descriptor(
  name='ParameterTypeInfo',
  full_name='yamcs.protobuf.mdb.ParameterTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='engType', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.engType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataEncoding', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.dataEncoding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unitSet', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.unitSet', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultAlarm', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.defaultAlarm', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.enumValue', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='absoluteTimeInfo', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.absoluteTimeInfo', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextAlarm', full_name='yamcs.protobuf.mdb.ParameterTypeInfo.contextAlarm', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2388,
)


_ABSOLUTETIMEINFO = _descriptor.Descriptor(
  name='AbsoluteTimeInfo',
  full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='initialValue', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.initialValue', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.scale', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offsetFrom', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.offsetFrom', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='yamcs.protobuf.mdb.AbsoluteTimeInfo.epoch', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2391,
  serialized_end=2532,
)


_USEDBYINFO = _descriptor.Descriptor(
  name='UsedByInfo',
  full_name='yamcs.protobuf.mdb.UsedByInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.mdb.UsedByInfo.algorithm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.UsedByInfo.container', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2534,
  serialized_end=2654,
)


_PARAMETERINFO = _descriptor.Descriptor(
  name='ParameterInfo',
  full_name='yamcs.protobuf.mdb.ParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ParameterInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.ParameterInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.ParameterInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.ParameterInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.ParameterInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ParameterInfo.type', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSource', full_name='yamcs.protobuf.mdb.ParameterInfo.dataSource', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedBy', full_name='yamcs.protobuf.mdb.ParameterInfo.usedBy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2657,
  serialized_end=2963,
)


_ARGUMENTTYPEINFO = _descriptor.Descriptor(
  name='ArgumentTypeInfo',
  full_name='yamcs.protobuf.mdb.ArgumentTypeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='engType', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.engType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataEncoding', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.dataEncoding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unitSet', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.unitSet', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.enumValue', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rangeMin', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.rangeMin', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rangeMax', full_name='yamcs.protobuf.mdb.ArgumentTypeInfo.rangeMax', index=5,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2966,
  serialized_end=3194,
)


_ARGUMENTINFO = _descriptor.Descriptor(
  name='ArgumentInfo',
  full_name='yamcs.protobuf.mdb.ArgumentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ArgumentInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.mdb.ArgumentInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initialValue', full_name='yamcs.protobuf.mdb.ArgumentInfo.initialValue', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ArgumentInfo.type', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3196,
  serialized_end=3319,
)


_ARGUMENTASSIGNMENTINFO = _descriptor.Descriptor(
  name='ArgumentAssignmentInfo',
  full_name='yamcs.protobuf.mdb.ArgumentAssignmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ArgumentAssignmentInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ArgumentAssignmentInfo.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3321,
  serialized_end=3374,
)


_SIGNIFICANCEINFO = _descriptor.Descriptor(
  name='SignificanceInfo',
  full_name='yamcs.protobuf.mdb.SignificanceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='consequenceLevel', full_name='yamcs.protobuf.mdb.SignificanceInfo.consequenceLevel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reasonForWarning', full_name='yamcs.protobuf.mdb.SignificanceInfo.reasonForWarning', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3377,
  serialized_end=3606,
)


_COMPARISONINFO = _descriptor.Descriptor(
  name='ComparisonInfo',
  full_name='yamcs.protobuf.mdb.ComparisonInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.ComparisonInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='yamcs.protobuf.mdb.ComparisonInfo.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.mdb.ComparisonInfo.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPARISONINFO_OPERATORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3609,
  serialized_end=3906,
)


_TRANSMISSIONCONSTRAINTINFO = _descriptor.Descriptor(
  name='TransmissionConstraintInfo',
  full_name='yamcs.protobuf.mdb.TransmissionConstraintInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='comparison', full_name='yamcs.protobuf.mdb.TransmissionConstraintInfo.comparison', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.mdb.TransmissionConstraintInfo.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3908,
  serialized_end=4009,
)


_COMMANDINFO = _descriptor.Descriptor(
  name='CommandInfo',
  full_name='yamcs.protobuf.mdb.CommandInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.CommandInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.CommandInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.CommandInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.CommandInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.CommandInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseCommand', full_name='yamcs.protobuf.mdb.CommandInfo.baseCommand', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abstract', full_name='yamcs.protobuf.mdb.CommandInfo.abstract', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.CommandInfo.argument', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argumentAssignment', full_name='yamcs.protobuf.mdb.CommandInfo.argumentAssignment', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='significance', full_name='yamcs.protobuf.mdb.CommandInfo.significance', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constraint', full_name='yamcs.protobuf.mdb.CommandInfo.constraint', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandContainer', full_name='yamcs.protobuf.mdb.CommandInfo.commandContainer', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4012,
  serialized_end=4551,
)


_REPEATINFO = _descriptor.Descriptor(
  name='RepeatInfo',
  full_name='yamcs.protobuf.mdb.RepeatInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fixedCount', full_name='yamcs.protobuf.mdb.RepeatInfo.fixedCount', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dynamicCount', full_name='yamcs.protobuf.mdb.RepeatInfo.dynamicCount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitsBetween', full_name='yamcs.protobuf.mdb.RepeatInfo.bitsBetween', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4553,
  serialized_end=4663,
)


_SEQUENCEENTRYINFO = _descriptor.Descriptor(
  name='SequenceEntryInfo',
  full_name='yamcs.protobuf.mdb.SequenceEntryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locationInBits', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.locationInBits', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenceLocation', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.referenceLocation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.container', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.parameter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='argument', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.argument', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixedValue', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.fixedValue', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repeat', full_name='yamcs.protobuf.mdb.SequenceEntryInfo.repeat', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4666,
  serialized_end=5127,
)


_FIXEDVALUEINFO = _descriptor.Descriptor(
  name='FixedValueInfo',
  full_name='yamcs.protobuf.mdb.FixedValueInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.FixedValueInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hexValue', full_name='yamcs.protobuf.mdb.FixedValueInfo.hexValue', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.FixedValueInfo.sizeInBits', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5129,
  serialized_end=5197,
)


_COMMANDCONTAINERINFO = _descriptor.Descriptor(
  name='CommandContainerInfo',
  full_name='yamcs.protobuf.mdb.CommandContainerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.CommandContainerInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.CommandContainerInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.CommandContainerInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.CommandContainerInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.CommandContainerInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.CommandContainerInfo.sizeInBits', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseContainer', full_name='yamcs.protobuf.mdb.CommandContainerInfo.baseContainer', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.mdb.CommandContainerInfo.entry', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5200,
  serialized_end=5495,
)


_CONTAINERINFO = _descriptor.Descriptor(
  name='ContainerInfo',
  full_name='yamcs.protobuf.mdb.ContainerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.ContainerInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.ContainerInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.ContainerInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.ContainerInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.ContainerInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxInterval', full_name='yamcs.protobuf.mdb.ContainerInfo.maxInterval', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeInBits', full_name='yamcs.protobuf.mdb.ContainerInfo.sizeInBits', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseContainer', full_name='yamcs.protobuf.mdb.ContainerInfo.baseContainer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restrictionCriteria', full_name='yamcs.protobuf.mdb.ContainerInfo.restrictionCriteria', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.mdb.ContainerInfo.entry', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='usedBy', full_name='yamcs.protobuf.mdb.ContainerInfo.usedBy', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5498,
  serialized_end=5913,
)


_INPUTPARAMETERINFO = _descriptor.Descriptor(
  name='InputParameterInfo',
  full_name='yamcs.protobuf.mdb.InputParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.InputParameterInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputName', full_name='yamcs.protobuf.mdb.InputParameterInfo.inputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterInstance', full_name='yamcs.protobuf.mdb.InputParameterInfo.parameterInstance', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mandatory', full_name='yamcs.protobuf.mdb.InputParameterInfo.mandatory', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5916,
  serialized_end=6055,
)


_OUTPUTPARAMETERINFO = _descriptor.Descriptor(
  name='OutputParameterInfo',
  full_name='yamcs.protobuf.mdb.OutputParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.OutputParameterInfo.parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputName', full_name='yamcs.protobuf.mdb.OutputParameterInfo.outputName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6057,
  serialized_end=6152,
)


_ALGORITHMINFO = _descriptor.Descriptor(
  name='AlgorithmInfo',
  full_name='yamcs.protobuf.mdb.AlgorithmInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.AlgorithmInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.AlgorithmInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.AlgorithmInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.AlgorithmInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alias', full_name='yamcs.protobuf.mdb.AlgorithmInfo.alias', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='yamcs.protobuf.mdb.AlgorithmInfo.scope', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='yamcs.protobuf.mdb.AlgorithmInfo.language', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='yamcs.protobuf.mdb.AlgorithmInfo.text', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputParameter', full_name='yamcs.protobuf.mdb.AlgorithmInfo.inputParameter', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputParameter', full_name='yamcs.protobuf.mdb.AlgorithmInfo.outputParameter', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onParameterUpdate', full_name='yamcs.protobuf.mdb.AlgorithmInfo.onParameterUpdate', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onPeriodicRate', full_name='yamcs.protobuf.mdb.AlgorithmInfo.onPeriodicRate', index=11,
      number=12, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALGORITHMINFO_SCOPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6155,
  serialized_end=6655,
)


_LISTPARAMETERSRESPONSE = _descriptor.Descriptor(
  name='ListParametersResponse',
  full_name='yamcs.protobuf.mdb.ListParametersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.ListParametersResponse.parameter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListParametersResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListParametersResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6657,
  serialized_end=6781,
)


_LISTPARAMETERTYPESRESPONSE = _descriptor.Descriptor(
  name='ListParameterTypesResponse',
  full_name='yamcs.protobuf.mdb.ListParameterTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.type', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListParameterTypesResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6783,
  serialized_end=6910,
)


_BULKGETPARAMETERINFOREQUEST = _descriptor.Descriptor(
  name='BulkGetParameterInfoRequest',
  full_name='yamcs.protobuf.mdb.BulkGetParameterInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.mdb.BulkGetParameterInfoRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6912,
  serialized_end=6984,
)


_BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE = _descriptor.Descriptor(
  name='GetParameterInfoResponse',
  full_name='yamcs.protobuf.mdb.BulkGetParameterInfoResponse.GetParameterInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.mdb.BulkGetParameterInfoResponse.GetParameterInfoResponse.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.mdb.BulkGetParameterInfoResponse.GetParameterInfoResponse.parameter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7112,
  serialized_end=7235,
)

_BULKGETPARAMETERINFORESPONSE = _descriptor.Descriptor(
  name='BulkGetParameterInfoResponse',
  full_name='yamcs.protobuf.mdb.BulkGetParameterInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='yamcs.protobuf.mdb.BulkGetParameterInfoResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6987,
  serialized_end=7235,
)


_LISTCONTAINERSRESPONSE = _descriptor.Descriptor(
  name='ListContainersResponse',
  full_name='yamcs.protobuf.mdb.ListContainersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container', full_name='yamcs.protobuf.mdb.ListContainersResponse.container', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListContainersResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListContainersResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7237,
  serialized_end=7361,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.mdb.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='yamcs.protobuf.mdb.ListCommandsResponse.command', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListCommandsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListCommandsResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7363,
  serialized_end=7481,
)


_LISTALGORITHMSRESPONSE = _descriptor.Descriptor(
  name='ListAlgorithmsResponse',
  full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.algorithm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListAlgorithmsResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7483,
  serialized_end=7607,
)


_LISTSPACESYSTEMSRESPONSE = _descriptor.Descriptor(
  name='ListSpaceSystemsResponse',
  full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spaceSystem', full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse.spaceSystem', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.mdb.ListSpaceSystemsResponse.totalSize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7610,
  serialized_end=7740,
)


_SPACESYSTEMINFO = _descriptor.Descriptor(
  name='SpaceSystemInfo',
  full_name='yamcs.protobuf.mdb.SpaceSystemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualifiedName', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.qualifiedName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shortDescription', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.shortDescription', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longDescription', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.longDescription', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterCount', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.parameterCount', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='containerCount', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.containerCount', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandCount', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.commandCount', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithmCount', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.algorithmCount', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='history', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.history', index=9,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub', full_name='yamcs.protobuf.mdb.SpaceSystemInfo.sub', index=10,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7743,
  serialized_end=8059,
)


_CHANGEPARAMETERREQUEST = _descriptor.Descriptor(
  name='ChangeParameterRequest',
  full_name='yamcs.protobuf.mdb.ChangeParameterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yamcs.protobuf.mdb.ChangeParameterRequest.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultCalibrator', full_name='yamcs.protobuf.mdb.ChangeParameterRequest.defaultCalibrator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextCalibrator', full_name='yamcs.protobuf.mdb.ChangeParameterRequest.contextCalibrator', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultAlarm', full_name='yamcs.protobuf.mdb.ChangeParameterRequest.defaultAlarm', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contextAlarm', full_name='yamcs.protobuf.mdb.ChangeParameterRequest.contextAlarm', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEPARAMETERREQUEST_ACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8062,
  serialized_end=8559,
)


_CHANGEALGORITHMREQUEST = _descriptor.Descriptor(
  name='ChangeAlgorithmRequest',
  full_name='yamcs.protobuf.mdb.ChangeAlgorithmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yamcs.protobuf.mdb.ChangeAlgorithmRequest.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='yamcs.protobuf.mdb.ChangeAlgorithmRequest.algorithm', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEALGORITHMREQUEST_ACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8562,
  serialized_end=8745,
)

_MISSIONDATABASE.fields_by_name['spaceSystem'].message_type = _SPACESYSTEMINFO
_ALARMRANGE.fields_by_name['level'].enum_type = _ALARMLEVELTYPE
_ENUMERATIONALARM.fields_by_name['level'].enum_type = _ALARMLEVELTYPE
_ALARMINFO.fields_by_name['staticAlarmRange'].message_type = _ALARMRANGE
_ALARMINFO.fields_by_name['enumerationAlarm'].message_type = _ENUMERATIONALARM
_CONTEXTALARMINFO.fields_by_name['comparison'].message_type = _COMPARISONINFO
_CONTEXTALARMINFO.fields_by_name['alarm'].message_type = _ALARMINFO
_DATAENCODINGINFO.fields_by_name['type'].enum_type = _DATAENCODINGINFO_TYPE
_DATAENCODINGINFO.fields_by_name['defaultCalibrator'].message_type = _CALIBRATORINFO
_DATAENCODINGINFO.fields_by_name['contextCalibrator'].message_type = _CONTEXTCALIBRATORINFO
_DATAENCODINGINFO_TYPE.containing_type = _DATAENCODINGINFO
_CONTEXTCALIBRATORINFO.fields_by_name['comparison'].message_type = _COMPARISONINFO
_CONTEXTCALIBRATORINFO.fields_by_name['calibrator'].message_type = _CALIBRATORINFO
_CALIBRATORINFO.fields_by_name['polynomialCalibrator'].message_type = _POLYNOMIALCALIBRATORINFO
_CALIBRATORINFO.fields_by_name['splineCalibrator'].message_type = _SPLINECALIBRATORINFO
_CALIBRATORINFO.fields_by_name['javaExpressionCalibrator'].message_type = _JAVAEXPRESSIONCALIBRATORINFO
_CALIBRATORINFO.fields_by_name['type'].enum_type = _CALIBRATORINFO_TYPE
_CALIBRATORINFO_TYPE.containing_type = _CALIBRATORINFO
_SPLINECALIBRATORINFO_SPLINEPOINTINFO.containing_type = _SPLINECALIBRATORINFO
_SPLINECALIBRATORINFO.fields_by_name['point'].message_type = _SPLINECALIBRATORINFO_SPLINEPOINTINFO
_PARAMETERTYPEINFO.fields_by_name['dataEncoding'].message_type = _DATAENCODINGINFO
_PARAMETERTYPEINFO.fields_by_name['unitSet'].message_type = _UNITINFO
_PARAMETERTYPEINFO.fields_by_name['defaultAlarm'].message_type = _ALARMINFO
_PARAMETERTYPEINFO.fields_by_name['enumValue'].message_type = _ENUMVALUE
_PARAMETERTYPEINFO.fields_by_name['absoluteTimeInfo'].message_type = _ABSOLUTETIMEINFO
_PARAMETERTYPEINFO.fields_by_name['contextAlarm'].message_type = _CONTEXTALARMINFO
_ABSOLUTETIMEINFO.fields_by_name['offsetFrom'].message_type = _PARAMETERINFO
_USEDBYINFO.fields_by_name['algorithm'].message_type = _ALGORITHMINFO
_USEDBYINFO.fields_by_name['container'].message_type = _CONTAINERINFO
_PARAMETERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_PARAMETERINFO.fields_by_name['type'].message_type = _PARAMETERTYPEINFO
_PARAMETERINFO.fields_by_name['dataSource'].enum_type = _DATASOURCETYPE
_PARAMETERINFO.fields_by_name['usedBy'].message_type = _USEDBYINFO
_ARGUMENTTYPEINFO.fields_by_name['dataEncoding'].message_type = _DATAENCODINGINFO
_ARGUMENTTYPEINFO.fields_by_name['unitSet'].message_type = _UNITINFO
_ARGUMENTTYPEINFO.fields_by_name['enumValue'].message_type = _ENUMVALUE
_ARGUMENTINFO.fields_by_name['type'].message_type = _ARGUMENTTYPEINFO
_SIGNIFICANCEINFO.fields_by_name['consequenceLevel'].enum_type = _SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE
_SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE.containing_type = _SIGNIFICANCEINFO
_COMPARISONINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_COMPARISONINFO.fields_by_name['operator'].enum_type = _COMPARISONINFO_OPERATORTYPE
_COMPARISONINFO_OPERATORTYPE.containing_type = _COMPARISONINFO
_TRANSMISSIONCONSTRAINTINFO.fields_by_name['comparison'].message_type = _COMPARISONINFO
_COMMANDINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_COMMANDINFO.fields_by_name['baseCommand'].message_type = _COMMANDINFO
_COMMANDINFO.fields_by_name['argument'].message_type = _ARGUMENTINFO
_COMMANDINFO.fields_by_name['argumentAssignment'].message_type = _ARGUMENTASSIGNMENTINFO
_COMMANDINFO.fields_by_name['significance'].message_type = _SIGNIFICANCEINFO
_COMMANDINFO.fields_by_name['constraint'].message_type = _TRANSMISSIONCONSTRAINTINFO
_COMMANDINFO.fields_by_name['commandContainer'].message_type = _COMMANDCONTAINERINFO
_REPEATINFO.fields_by_name['dynamicCount'].message_type = _PARAMETERINFO
_SEQUENCEENTRYINFO.fields_by_name['referenceLocation'].enum_type = _SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE
_SEQUENCEENTRYINFO.fields_by_name['container'].message_type = _CONTAINERINFO
_SEQUENCEENTRYINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_SEQUENCEENTRYINFO.fields_by_name['argument'].message_type = _ARGUMENTINFO
_SEQUENCEENTRYINFO.fields_by_name['fixedValue'].message_type = _FIXEDVALUEINFO
_SEQUENCEENTRYINFO.fields_by_name['repeat'].message_type = _REPEATINFO
_SEQUENCEENTRYINFO_REFERENCELOCATIONTYPE.containing_type = _SEQUENCEENTRYINFO
_COMMANDCONTAINERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_COMMANDCONTAINERINFO.fields_by_name['baseContainer'].message_type = _COMMANDCONTAINERINFO
_COMMANDCONTAINERINFO.fields_by_name['entry'].message_type = _SEQUENCEENTRYINFO
_CONTAINERINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_CONTAINERINFO.fields_by_name['baseContainer'].message_type = _CONTAINERINFO
_CONTAINERINFO.fields_by_name['restrictionCriteria'].message_type = _COMPARISONINFO
_CONTAINERINFO.fields_by_name['entry'].message_type = _SEQUENCEENTRYINFO
_CONTAINERINFO.fields_by_name['usedBy'].message_type = _USEDBYINFO
_INPUTPARAMETERINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_OUTPUTPARAMETERINFO.fields_by_name['parameter'].message_type = _PARAMETERINFO
_ALGORITHMINFO.fields_by_name['alias'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_ALGORITHMINFO.fields_by_name['scope'].enum_type = _ALGORITHMINFO_SCOPE
_ALGORITHMINFO.fields_by_name['inputParameter'].message_type = _INPUTPARAMETERINFO
_ALGORITHMINFO.fields_by_name['outputParameter'].message_type = _OUTPUTPARAMETERINFO
_ALGORITHMINFO.fields_by_name['onParameterUpdate'].message_type = _PARAMETERINFO
_ALGORITHMINFO_SCOPE.containing_type = _ALGORITHMINFO
_LISTPARAMETERSRESPONSE.fields_by_name['parameter'].message_type = _PARAMETERINFO
_LISTPARAMETERTYPESRESPONSE.fields_by_name['type'].message_type = _PARAMETERTYPEINFO
_BULKGETPARAMETERINFOREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE.fields_by_name['parameter'].message_type = _PARAMETERINFO
_BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE.containing_type = _BULKGETPARAMETERINFORESPONSE
_BULKGETPARAMETERINFORESPONSE.fields_by_name['response'].message_type = _BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE
_LISTCONTAINERSRESPONSE.fields_by_name['container'].message_type = _CONTAINERINFO
_LISTCOMMANDSRESPONSE.fields_by_name['command'].message_type = _COMMANDINFO
_LISTALGORITHMSRESPONSE.fields_by_name['algorithm'].message_type = _ALGORITHMINFO
_LISTSPACESYSTEMSRESPONSE.fields_by_name['spaceSystem'].message_type = _SPACESYSTEMINFO
_SPACESYSTEMINFO.fields_by_name['history'].message_type = _HISTORYINFO
_SPACESYSTEMINFO.fields_by_name['sub'].message_type = _SPACESYSTEMINFO
_CHANGEPARAMETERREQUEST.fields_by_name['action'].enum_type = _CHANGEPARAMETERREQUEST_ACTIONTYPE
_CHANGEPARAMETERREQUEST.fields_by_name['defaultCalibrator'].message_type = _CALIBRATORINFO
_CHANGEPARAMETERREQUEST.fields_by_name['contextCalibrator'].message_type = _CONTEXTCALIBRATORINFO
_CHANGEPARAMETERREQUEST.fields_by_name['defaultAlarm'].message_type = _ALARMINFO
_CHANGEPARAMETERREQUEST.fields_by_name['contextAlarm'].message_type = _CONTEXTALARMINFO
_CHANGEPARAMETERREQUEST_ACTIONTYPE.containing_type = _CHANGEPARAMETERREQUEST
_CHANGEALGORITHMREQUEST.fields_by_name['action'].enum_type = _CHANGEALGORITHMREQUEST_ACTIONTYPE
_CHANGEALGORITHMREQUEST.fields_by_name['algorithm'].message_type = _ALGORITHMINFO
_CHANGEALGORITHMREQUEST_ACTIONTYPE.containing_type = _CHANGEALGORITHMREQUEST
DESCRIPTOR.message_types_by_name['MissionDatabase'] = _MISSIONDATABASE
DESCRIPTOR.message_types_by_name['HistoryInfo'] = _HISTORYINFO
DESCRIPTOR.message_types_by_name['UnitInfo'] = _UNITINFO
DESCRIPTOR.message_types_by_name['AlarmRange'] = _ALARMRANGE
DESCRIPTOR.message_types_by_name['EnumerationAlarm'] = _ENUMERATIONALARM
DESCRIPTOR.message_types_by_name['AlarmInfo'] = _ALARMINFO
DESCRIPTOR.message_types_by_name['ContextAlarmInfo'] = _CONTEXTALARMINFO
DESCRIPTOR.message_types_by_name['DataEncodingInfo'] = _DATAENCODINGINFO
DESCRIPTOR.message_types_by_name['ContextCalibratorInfo'] = _CONTEXTCALIBRATORINFO
DESCRIPTOR.message_types_by_name['CalibratorInfo'] = _CALIBRATORINFO
DESCRIPTOR.message_types_by_name['PolynomialCalibratorInfo'] = _POLYNOMIALCALIBRATORINFO
DESCRIPTOR.message_types_by_name['SplineCalibratorInfo'] = _SPLINECALIBRATORINFO
DESCRIPTOR.message_types_by_name['JavaExpressionCalibratorInfo'] = _JAVAEXPRESSIONCALIBRATORINFO
DESCRIPTOR.message_types_by_name['EnumValue'] = _ENUMVALUE
DESCRIPTOR.message_types_by_name['ParameterTypeInfo'] = _PARAMETERTYPEINFO
DESCRIPTOR.message_types_by_name['AbsoluteTimeInfo'] = _ABSOLUTETIMEINFO
DESCRIPTOR.message_types_by_name['UsedByInfo'] = _USEDBYINFO
DESCRIPTOR.message_types_by_name['ParameterInfo'] = _PARAMETERINFO
DESCRIPTOR.message_types_by_name['ArgumentTypeInfo'] = _ARGUMENTTYPEINFO
DESCRIPTOR.message_types_by_name['ArgumentInfo'] = _ARGUMENTINFO
DESCRIPTOR.message_types_by_name['ArgumentAssignmentInfo'] = _ARGUMENTASSIGNMENTINFO
DESCRIPTOR.message_types_by_name['SignificanceInfo'] = _SIGNIFICANCEINFO
DESCRIPTOR.message_types_by_name['ComparisonInfo'] = _COMPARISONINFO
DESCRIPTOR.message_types_by_name['TransmissionConstraintInfo'] = _TRANSMISSIONCONSTRAINTINFO
DESCRIPTOR.message_types_by_name['CommandInfo'] = _COMMANDINFO
DESCRIPTOR.message_types_by_name['RepeatInfo'] = _REPEATINFO
DESCRIPTOR.message_types_by_name['SequenceEntryInfo'] = _SEQUENCEENTRYINFO
DESCRIPTOR.message_types_by_name['FixedValueInfo'] = _FIXEDVALUEINFO
DESCRIPTOR.message_types_by_name['CommandContainerInfo'] = _COMMANDCONTAINERINFO
DESCRIPTOR.message_types_by_name['ContainerInfo'] = _CONTAINERINFO
DESCRIPTOR.message_types_by_name['InputParameterInfo'] = _INPUTPARAMETERINFO
DESCRIPTOR.message_types_by_name['OutputParameterInfo'] = _OUTPUTPARAMETERINFO
DESCRIPTOR.message_types_by_name['AlgorithmInfo'] = _ALGORITHMINFO
DESCRIPTOR.message_types_by_name['ListParametersResponse'] = _LISTPARAMETERSRESPONSE
DESCRIPTOR.message_types_by_name['ListParameterTypesResponse'] = _LISTPARAMETERTYPESRESPONSE
DESCRIPTOR.message_types_by_name['BulkGetParameterInfoRequest'] = _BULKGETPARAMETERINFOREQUEST
DESCRIPTOR.message_types_by_name['BulkGetParameterInfoResponse'] = _BULKGETPARAMETERINFORESPONSE
DESCRIPTOR.message_types_by_name['ListContainersResponse'] = _LISTCONTAINERSRESPONSE
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['ListAlgorithmsResponse'] = _LISTALGORITHMSRESPONSE
DESCRIPTOR.message_types_by_name['ListSpaceSystemsResponse'] = _LISTSPACESYSTEMSRESPONSE
DESCRIPTOR.message_types_by_name['SpaceSystemInfo'] = _SPACESYSTEMINFO
DESCRIPTOR.message_types_by_name['ChangeParameterRequest'] = _CHANGEPARAMETERREQUEST
DESCRIPTOR.message_types_by_name['ChangeAlgorithmRequest'] = _CHANGEALGORITHMREQUEST
DESCRIPTOR.enum_types_by_name['DataSourceType'] = _DATASOURCETYPE
DESCRIPTOR.enum_types_by_name['AlarmLevelType'] = _ALARMLEVELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MissionDatabase = _reflection.GeneratedProtocolMessageType('MissionDatabase', (_message.Message,), dict(
  DESCRIPTOR = _MISSIONDATABASE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.MissionDatabase)
  ))
_sym_db.RegisterMessage(MissionDatabase)

HistoryInfo = _reflection.GeneratedProtocolMessageType('HistoryInfo', (_message.Message,), dict(
  DESCRIPTOR = _HISTORYINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.HistoryInfo)
  ))
_sym_db.RegisterMessage(HistoryInfo)

UnitInfo = _reflection.GeneratedProtocolMessageType('UnitInfo', (_message.Message,), dict(
  DESCRIPTOR = _UNITINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.UnitInfo)
  ))
_sym_db.RegisterMessage(UnitInfo)

AlarmRange = _reflection.GeneratedProtocolMessageType('AlarmRange', (_message.Message,), dict(
  DESCRIPTOR = _ALARMRANGE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AlarmRange)
  ))
_sym_db.RegisterMessage(AlarmRange)

EnumerationAlarm = _reflection.GeneratedProtocolMessageType('EnumerationAlarm', (_message.Message,), dict(
  DESCRIPTOR = _ENUMERATIONALARM,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.EnumerationAlarm)
  ))
_sym_db.RegisterMessage(EnumerationAlarm)

AlarmInfo = _reflection.GeneratedProtocolMessageType('AlarmInfo', (_message.Message,), dict(
  DESCRIPTOR = _ALARMINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AlarmInfo)
  ))
_sym_db.RegisterMessage(AlarmInfo)

ContextAlarmInfo = _reflection.GeneratedProtocolMessageType('ContextAlarmInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONTEXTALARMINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContextAlarmInfo)
  ))
_sym_db.RegisterMessage(ContextAlarmInfo)

DataEncodingInfo = _reflection.GeneratedProtocolMessageType('DataEncodingInfo', (_message.Message,), dict(
  DESCRIPTOR = _DATAENCODINGINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.DataEncodingInfo)
  ))
_sym_db.RegisterMessage(DataEncodingInfo)

ContextCalibratorInfo = _reflection.GeneratedProtocolMessageType('ContextCalibratorInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONTEXTCALIBRATORINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContextCalibratorInfo)
  ))
_sym_db.RegisterMessage(ContextCalibratorInfo)

CalibratorInfo = _reflection.GeneratedProtocolMessageType('CalibratorInfo', (_message.Message,), dict(
  DESCRIPTOR = _CALIBRATORINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CalibratorInfo)
  ))
_sym_db.RegisterMessage(CalibratorInfo)

PolynomialCalibratorInfo = _reflection.GeneratedProtocolMessageType('PolynomialCalibratorInfo', (_message.Message,), dict(
  DESCRIPTOR = _POLYNOMIALCALIBRATORINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.PolynomialCalibratorInfo)
  ))
_sym_db.RegisterMessage(PolynomialCalibratorInfo)

SplineCalibratorInfo = _reflection.GeneratedProtocolMessageType('SplineCalibratorInfo', (_message.Message,), dict(

  SplinePointInfo = _reflection.GeneratedProtocolMessageType('SplinePointInfo', (_message.Message,), dict(
    DESCRIPTOR = _SPLINECALIBRATORINFO_SPLINEPOINTINFO,
    __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SplineCalibratorInfo.SplinePointInfo)
    ))
  ,
  DESCRIPTOR = _SPLINECALIBRATORINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SplineCalibratorInfo)
  ))
_sym_db.RegisterMessage(SplineCalibratorInfo)
_sym_db.RegisterMessage(SplineCalibratorInfo.SplinePointInfo)

JavaExpressionCalibratorInfo = _reflection.GeneratedProtocolMessageType('JavaExpressionCalibratorInfo', (_message.Message,), dict(
  DESCRIPTOR = _JAVAEXPRESSIONCALIBRATORINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.JavaExpressionCalibratorInfo)
  ))
_sym_db.RegisterMessage(JavaExpressionCalibratorInfo)

EnumValue = _reflection.GeneratedProtocolMessageType('EnumValue', (_message.Message,), dict(
  DESCRIPTOR = _ENUMVALUE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.EnumValue)
  ))
_sym_db.RegisterMessage(EnumValue)

ParameterTypeInfo = _reflection.GeneratedProtocolMessageType('ParameterTypeInfo', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERTYPEINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterTypeInfo)
  ))
_sym_db.RegisterMessage(ParameterTypeInfo)

AbsoluteTimeInfo = _reflection.GeneratedProtocolMessageType('AbsoluteTimeInfo', (_message.Message,), dict(
  DESCRIPTOR = _ABSOLUTETIMEINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AbsoluteTimeInfo)
  ))
_sym_db.RegisterMessage(AbsoluteTimeInfo)

UsedByInfo = _reflection.GeneratedProtocolMessageType('UsedByInfo', (_message.Message,), dict(
  DESCRIPTOR = _USEDBYINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.UsedByInfo)
  ))
_sym_db.RegisterMessage(UsedByInfo)

ParameterInfo = _reflection.GeneratedProtocolMessageType('ParameterInfo', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ParameterInfo)
  ))
_sym_db.RegisterMessage(ParameterInfo)

ArgumentTypeInfo = _reflection.GeneratedProtocolMessageType('ArgumentTypeInfo', (_message.Message,), dict(
  DESCRIPTOR = _ARGUMENTTYPEINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentTypeInfo)
  ))
_sym_db.RegisterMessage(ArgumentTypeInfo)

ArgumentInfo = _reflection.GeneratedProtocolMessageType('ArgumentInfo', (_message.Message,), dict(
  DESCRIPTOR = _ARGUMENTINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentInfo)
  ))
_sym_db.RegisterMessage(ArgumentInfo)

ArgumentAssignmentInfo = _reflection.GeneratedProtocolMessageType('ArgumentAssignmentInfo', (_message.Message,), dict(
  DESCRIPTOR = _ARGUMENTASSIGNMENTINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ArgumentAssignmentInfo)
  ))
_sym_db.RegisterMessage(ArgumentAssignmentInfo)

SignificanceInfo = _reflection.GeneratedProtocolMessageType('SignificanceInfo', (_message.Message,), dict(
  DESCRIPTOR = _SIGNIFICANCEINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SignificanceInfo)
  ))
_sym_db.RegisterMessage(SignificanceInfo)

ComparisonInfo = _reflection.GeneratedProtocolMessageType('ComparisonInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMPARISONINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ComparisonInfo)
  ))
_sym_db.RegisterMessage(ComparisonInfo)

TransmissionConstraintInfo = _reflection.GeneratedProtocolMessageType('TransmissionConstraintInfo', (_message.Message,), dict(
  DESCRIPTOR = _TRANSMISSIONCONSTRAINTINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.TransmissionConstraintInfo)
  ))
_sym_db.RegisterMessage(TransmissionConstraintInfo)

CommandInfo = _reflection.GeneratedProtocolMessageType('CommandInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CommandInfo)
  ))
_sym_db.RegisterMessage(CommandInfo)

RepeatInfo = _reflection.GeneratedProtocolMessageType('RepeatInfo', (_message.Message,), dict(
  DESCRIPTOR = _REPEATINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.RepeatInfo)
  ))
_sym_db.RegisterMessage(RepeatInfo)

SequenceEntryInfo = _reflection.GeneratedProtocolMessageType('SequenceEntryInfo', (_message.Message,), dict(
  DESCRIPTOR = _SEQUENCEENTRYINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SequenceEntryInfo)
  ))
_sym_db.RegisterMessage(SequenceEntryInfo)

FixedValueInfo = _reflection.GeneratedProtocolMessageType('FixedValueInfo', (_message.Message,), dict(
  DESCRIPTOR = _FIXEDVALUEINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.FixedValueInfo)
  ))
_sym_db.RegisterMessage(FixedValueInfo)

CommandContainerInfo = _reflection.GeneratedProtocolMessageType('CommandContainerInfo', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCONTAINERINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.CommandContainerInfo)
  ))
_sym_db.RegisterMessage(CommandContainerInfo)

ContainerInfo = _reflection.GeneratedProtocolMessageType('ContainerInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ContainerInfo)
  ))
_sym_db.RegisterMessage(ContainerInfo)

InputParameterInfo = _reflection.GeneratedProtocolMessageType('InputParameterInfo', (_message.Message,), dict(
  DESCRIPTOR = _INPUTPARAMETERINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.InputParameterInfo)
  ))
_sym_db.RegisterMessage(InputParameterInfo)

OutputParameterInfo = _reflection.GeneratedProtocolMessageType('OutputParameterInfo', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUTPARAMETERINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.OutputParameterInfo)
  ))
_sym_db.RegisterMessage(OutputParameterInfo)

AlgorithmInfo = _reflection.GeneratedProtocolMessageType('AlgorithmInfo', (_message.Message,), dict(
  DESCRIPTOR = _ALGORITHMINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.AlgorithmInfo)
  ))
_sym_db.RegisterMessage(AlgorithmInfo)

ListParametersResponse = _reflection.GeneratedProtocolMessageType('ListParametersResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPARAMETERSRESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListParametersResponse)
  ))
_sym_db.RegisterMessage(ListParametersResponse)

ListParameterTypesResponse = _reflection.GeneratedProtocolMessageType('ListParameterTypesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPARAMETERTYPESRESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListParameterTypesResponse)
  ))
_sym_db.RegisterMessage(ListParameterTypesResponse)

BulkGetParameterInfoRequest = _reflection.GeneratedProtocolMessageType('BulkGetParameterInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _BULKGETPARAMETERINFOREQUEST,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.BulkGetParameterInfoRequest)
  ))
_sym_db.RegisterMessage(BulkGetParameterInfoRequest)

BulkGetParameterInfoResponse = _reflection.GeneratedProtocolMessageType('BulkGetParameterInfoResponse', (_message.Message,), dict(

  GetParameterInfoResponse = _reflection.GeneratedProtocolMessageType('GetParameterInfoResponse', (_message.Message,), dict(
    DESCRIPTOR = _BULKGETPARAMETERINFORESPONSE_GETPARAMETERINFORESPONSE,
    __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.BulkGetParameterInfoResponse.GetParameterInfoResponse)
    ))
  ,
  DESCRIPTOR = _BULKGETPARAMETERINFORESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.BulkGetParameterInfoResponse)
  ))
_sym_db.RegisterMessage(BulkGetParameterInfoResponse)
_sym_db.RegisterMessage(BulkGetParameterInfoResponse.GetParameterInfoResponse)

ListContainersResponse = _reflection.GeneratedProtocolMessageType('ListContainersResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCONTAINERSRESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListContainersResponse)
  ))
_sym_db.RegisterMessage(ListContainersResponse)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCOMMANDSRESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListCommandsResponse)
  ))
_sym_db.RegisterMessage(ListCommandsResponse)

ListAlgorithmsResponse = _reflection.GeneratedProtocolMessageType('ListAlgorithmsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTALGORITHMSRESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListAlgorithmsResponse)
  ))
_sym_db.RegisterMessage(ListAlgorithmsResponse)

ListSpaceSystemsResponse = _reflection.GeneratedProtocolMessageType('ListSpaceSystemsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTSPACESYSTEMSRESPONSE,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ListSpaceSystemsResponse)
  ))
_sym_db.RegisterMessage(ListSpaceSystemsResponse)

SpaceSystemInfo = _reflection.GeneratedProtocolMessageType('SpaceSystemInfo', (_message.Message,), dict(
  DESCRIPTOR = _SPACESYSTEMINFO,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.SpaceSystemInfo)
  ))
_sym_db.RegisterMessage(SpaceSystemInfo)

ChangeParameterRequest = _reflection.GeneratedProtocolMessageType('ChangeParameterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEPARAMETERREQUEST,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ChangeParameterRequest)
  ))
_sym_db.RegisterMessage(ChangeParameterRequest)

ChangeAlgorithmRequest = _reflection.GeneratedProtocolMessageType('ChangeAlgorithmRequest', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEALGORITHMREQUEST,
  __module__ = 'yamcs.protobuf.mdb.mdb_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.mdb.ChangeAlgorithmRequest)
  ))
_sym_db.RegisterMessage(ChangeAlgorithmRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
